# bwa and bwa-meth Docker images

We build two Docker images that provide the bwa aligner and the bwa mem-based bisulfite aligner, bwa-meth. The first image is a base image containing the software. The second image uses the base image to build the indexes and include them.
